==> mall-center-api-0.1.13.37-20211127.054811-3-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/UserDiscountTicketWrapper.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import cn.com.duiba.mall.center.api.domain.vo.DiscountTicketVo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author fja
 */
public class UserDiscountTicketWrapper implements Serializable {

    List<DiscountTicketVo> userAcquiredTicketVos;

    List<DiscountTicketVo> userCanAcquiredTicketVos;


    List<DiscountTicketDto> userAcquiredTicketDtos;

    List<DiscountTicketDto> userCanAcquiredTicketDtos;

    Map<Long, List<ConsumerDiscountDto>> discountId2UnusedTicketRecordsMap = Maps.newHashMap();

    public List<DiscountTicketVo> getUserAcquiredTicketVos() {
        return userAcquiredTicketVos;
    }

    public List<DiscountTicketVo> getUserCanAcquiredTicketVos() {
        return userCanAcquiredTicketVos;
    }

    public List<DiscountTicketDto> getUserAcquiredTicketDtos() {
        return userAcquiredTicketDtos;
    }

    public void setUserAcquiredTicketDtos(List<DiscountTicketDto> userAcquiredTicketDtos) {
        this.userAcquiredTicketDtos = userAcquiredTicketDtos;
    }

    public List<DiscountTicketDto> getUserCanAcquiredTicketDtos() {
        return userCanAcquiredTicketDtos;
    }

    public void setUserCanAcquiredTicketDtos(List<DiscountTicketDto> userCanAcquiredTicketDtos) {
        this.userCanAcquiredTicketDtos = userCanAcquiredTicketDtos;
    }

    public void setUserAcquiredTicketVos(List<DiscountTicketVo> userAcquiredTicketVos) {
        this.userAcquiredTicketVos = userAcquiredTicketVos;
    }

    public void setUserCanAcquiredTicketVos(List<DiscountTicketVo> userCanAcquiredTicketVos) {
        this.userCanAcquiredTicketVos = userCanAcquiredTicketVos;
    }

    public void setDiscountId2UnusedTicketRecordsMap(Map<Long, List<ConsumerDiscountDto>> discountId2UnusedTicketRecordsMap) {
        this.discountId2UnusedTicketRecordsMap = discountId2UnusedTicketRecordsMap;
    }

    public Map<Long, List<ConsumerDiscountDto>> getDiscountId2UnusedTicketRecordsMap() {
        return discountId2UnusedTicketRecordsMap;
    }

    public UserDiscountTicketWrapper() {}

    public UserDiscountTicketWrapper(List<DiscountTicketDto> userAcquiredTicketDtos, List<DiscountTicketDto> userCanAcquiredTicketDtos) {
        this.userAcquiredTicketDtos = userAcquiredTicketDtos;
        this.userCanAcquiredTicketDtos = userCanAcquiredTicketDtos;
    }

    /**
     * 合并优惠券
     * @return -
     */
    public List<DiscountTicketDto> getAllTicketDtos() {
        ArrayList<DiscountTicketDto> tickets = Lists.newArrayList(this.userAcquiredTicketDtos);
        tickets.addAll(this.userCanAcquiredTicketDtos);
        return tickets;
    }
}

==> mall-center-api-0.1.33-20251013.092126-2-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/UserDiscountTicketWrapper.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import cn.com.duiba.mall.center.api.domain.vo.DiscountTicketVo;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author fja
 */
public class UserDiscountTicketWrapper implements Serializable {

    List<DiscountTicketVo> userAcquiredTicketVos = Lists.newArrayList();

    List<DiscountTicketVo> userCanAcquiredTicketVos = Lists.newArrayList();;


    List<DiscountTicketDto> userAcquiredTicketDtos;

    List<DiscountTicketDto> userCanAcquiredTicketDtos;

    Map<Long, List<ConsumerDiscountDto>> discountId2UnusedTicketRecordsMap = Maps.newHashMap();

    public List<DiscountTicketVo> getUserAcquiredTicketVos() {
        return userAcquiredTicketVos;
    }

    public List<DiscountTicketVo> getUserCanAcquiredTicketVos() {
        return userCanAcquiredTicketVos;
    }

    public List<DiscountTicketDto> getUserAcquiredTicketDtos() {
        return userAcquiredTicketDtos;
    }

    public void setUserAcquiredTicketDtos(List<DiscountTicketDto> userAcquiredTicketDtos) {
        this.userAcquiredTicketDtos = userAcquiredTicketDtos;
    }

    public List<DiscountTicketDto> getUserCanAcquiredTicketDtos() {
        return userCanAcquiredTicketDtos;
    }

    public void setUserCanAcquiredTicketDtos(List<DiscountTicketDto> userCanAcquiredTicketDtos) {
        this.userCanAcquiredTicketDtos = userCanAcquiredTicketDtos;
    }

    public void setUserAcquiredTicketVos(List<DiscountTicketVo> userAcquiredTicketVos) {
        this.userAcquiredTicketVos = userAcquiredTicketVos;
    }

    public void setUserCanAcquiredTicketVos(List<DiscountTicketVo> userCanAcquiredTicketVos) {
        this.userCanAcquiredTicketVos = userCanAcquiredTicketVos;
    }

    public void setDiscountId2UnusedTicketRecordsMap(Map<Long, List<ConsumerDiscountDto>> discountId2UnusedTicketRecordsMap) {
        this.discountId2UnusedTicketRecordsMap = discountId2UnusedTicketRecordsMap;
    }

    public Map<Long, List<ConsumerDiscountDto>> getDiscountId2UnusedTicketRecordsMap() {
        return discountId2UnusedTicketRecordsMap;
    }

    public UserDiscountTicketWrapper() {}


    /**
     * 合并优惠券
     * @return -
     */
    public List<DiscountTicketDto> getAllTicketDtos() {
        ArrayList<DiscountTicketDto> tickets = Lists.newArrayList(this.userAcquiredTicketDtos);
        tickets.addAll(this.userCanAcquiredTicketDtos);
        return tickets;
    }
}
